###################################################
### chunk number 1: 
###################################################
library(interval)
data(bcos)
head(bcos)


###################################################
### chunk number 2: 
###################################################
fit1<-icfit(Surv(left,right,type="interval2")~treatment,data=bcos)
summary(fit1)


###################################################
### chunk number 3: 
###################################################
plot(fit1)


###################################################
### chunk number 4: 
###################################################
icout<-ictest(Surv(left,right,type="interval2")~treatment,data=bcos)
icout


###################################################
### chunk number 5: 
###################################################
plot(fit1,dtype="link")


###################################################
### chunk number 6: 
###################################################
ictest(Surv(left,right,type="interval2")~treatment,data=bcos,
initfit=icout$fit,scores="logrank2")


###################################################
### chunk number 7: 
###################################################
L<-bcos$left
R<-bcos$right
trt<-bcos$treatment 
ictest(L,R,trt,scores="wmw",initfit=icout$fit)


###################################################
### chunk number 8: 
###################################################
set.seed(1232)
fakeTrtGrps<-sample(letters[1:4],dim(bcos)[[1]],replace=TRUE)
ictest(L,R,fakeTrtGrps)


###################################################
### chunk number 9: 
###################################################
set.seed(931)
fakeZ<-rnorm(dim(bcos)[[1]])
ictest(L,R,fakeZ,alternative="less")


###################################################
### chunk number 10: 
###################################################
ictest(Surv(left,right,type="interval2")~treatment,data=bcos,exact=TRUE,scores="logrank1")


###################################################
### chunk number 11: 
###################################################
ictest(Surv(left,right,type="interval2")~treatment,data=bcos,initfit=icout$fit,method="scoretest",scores="logrank2")


###################################################
### chunk number 12: 
###################################################
icoutHLY<-ictest(Surv(left,right,type="interval2")~treatment,data=bcos,initfit=icout$fit,method="wsr.HLY",mcontrol=mControl(nwsr=99),scores="logrank1")
icoutHLY


###################################################
### chunk number 13: 
###################################################
icoutHLY$fit$anypzero


###################################################
### chunk number 14: 
###################################################
data(ChickWeight)
head(ChickWeight)


###################################################
### chunk number 15: 
###################################################
permTS(weight~Diet,data=ChickWeight,subset=Diet %in% c(3,4) & Time==21)


###################################################
### chunk number 16: 
###################################################
y3<-ChickWeight[ChickWeight$Time==21 & ChickWeight$Diet==3,"weight"]
y4<-ChickWeight[ChickWeight$Time==21 & ChickWeight$Diet==4,"weight"]
permTS(y3,y4)


###################################################
### chunk number 17: 
###################################################
permTS(y3[1:5],y4[1:5])


###################################################
### chunk number 18: 
###################################################
permKS(weight~Diet,data=ChickWeight,subset=Time==21)


###################################################
### chunk number 19: 
###################################################
y<-ChickWeight[ChickWeight$Time==21,"weight"]
g<-ChickWeight[ChickWeight$Time==21,"Diet"]
permKS(y,g)


###################################################
### chunk number 20: 
###################################################
permTREND(y,as.numeric(g))


###################################################
### chunk number 21: 
###################################################
system.time(cm19c10<-chooseMatrix(length(y3)+length(y4),
   length(y3)))
system.time(permTS(y3,y4,method="exact.ce",
   control=permControl(cm=cm19c10)))
system.time(permTS(y3,y4,method="exact.network",
   control=permControl(cm=cm19c10)))


###################################################
### chunk number 22: 
###################################################
icout<-ictest(Surv(left,right,type="interval2")~treatment,data=bcos,scores="wmw")
wmw.scores<-icout$scores
logistic.scores<-ictest(Surv(left,right,type="interval2")~treatment,data=bcos,
    icFIT=icout$fit,scores="general",dqfunc=function(x){ dlogis(qlogis(x))})$scores
max(abs(wmw.scores-logistic.scores))


###################################################
### chunk number 23: 
###################################################
library(coin)
independence_test(Surv(left,right,type="interval2")~treatment,data=bcos,ytrafo=wlr_trafo)


###################################################
### chunk number 24: 
###################################################
SUBSET<-c(1:5,50:65)
independence_test(Surv(left,right,type="interval2")~treatment,data=bcos,subset=SUBSET,ytrafo=wlr_trafo,distribution=exact())
ictest(Surv(left,right,type="interval2")~treatment,data=bcos,subset=SUBSET,method="exact.network")


###################################################
### chunk number 25: 
###################################################
ictest(Surv(left,right,type="interval2")~treatment,data=bcos,subset=SUBSET,method="exact.network",alternative="two.sidedAbs")


###################################################
### chunk number 26: 
###################################################
SUBSET2<-c(1:12,47:58)
system.time(
independence_test(Surv(left,right,type="interval2")~treatment,data=bcos,subset=SUBSET2,ytrafo=wlr_trafo,distribution=exact())
)
system.time(
ictest(Surv(left,right,type="interval2")~treatment,data=bcos,subset=SUBSET2,method="exact.network",alternative="two.sidedAbs")
)


###################################################
### chunk number 27: 
###################################################
L<-c(2,5,1,1,9,8,10)
R<-c(3,6,7,7,12,10,13)
group<-c(0,0,1,1,0,1,0)
example1<-data.frame(L,R,group)
example1


###################################################
### chunk number 28: 
###################################################
library(interval)
summary(icfit(L,R),digits=12)


###################################################
### chunk number 29: 
###################################################
print(3/14,digits=12)


###################################################
### chunk number 30: 
###################################################
score1<-wlr_trafo(Surv(L,R,type="interval2"))
cm<-chooseMatrix(7,3)
T<- ( (1-cm) %*% score1 )/4 - ( cm %*% score1 )/3   
cbind(cm,T)[order(T),][1:9,]


###################################################
### chunk number 31: 
###################################################
ictest.alone<-function(){
    ictest(Surv(left,right,type="interval2")~treatment,data=bcos)$p.value
}
library(Icens)
emicm.first<-function(){
    npmle<-EMICM(bcos[,c("left","right")]) 
    ictest(Surv(left,right,type="interval2")~treatment,data=bcos,initfit=npmle)$p.value
}
ictest.alone()
emicm.first()
system.time(ictest.alone())
system.time(emicm.first())


